
import { createRoot } from 'react-dom/client'
import { ClerkProvider } from '@clerk/clerk-react'
import { HelmetProvider } from "react-helmet-async"
import { QueryProvider } from "@/providers/QueryProvider"
import { CurrencyProvider } from "@/contexts/CurrencyContext"
import App from './App.tsx'
import './index.css'

// Use environment variable for Clerk publishable key
const PUBLISHABLE_KEY = import.meta.env.VITE_CLERK_PUBLISHABLE_KEY || "pk_live_Y2xlcmsuYXJjaGl0cmFrLmNvbSQ"

if (!PUBLISHABLE_KEY) {
  throw new Error("Missing Clerk Publishable Key. Please set VITE_CLERK_PUBLISHABLE_KEY environment variable.")
}

// Add error handling to prevent console spam from auth issues
const originalConsoleError = console.error;
console.error = (...args) => {
  // Filter out Clerk auth errors to reduce console spam
  const errorMessage = args.join(' ');
  if (errorMessage.includes('Browser unauthenticated') || 
      errorMessage.includes('clerk.accounts.dev') ||
      errorMessage.includes('dev_browser_unauthenticated')) {
    return; // Silently ignore these specific errors
  }
  originalConsoleError(...args);
};

// Enhanced Clerk appearance configuration with optimized performance
const clerkAppearance = {
  variables: {
    colorPrimary: 'hsl(var(--primary))',
    colorBackground: 'hsl(var(--card))',
    colorInputBackground: 'hsl(var(--input))',
    colorInputText: 'hsl(var(--foreground))',
    colorText: 'hsl(var(--foreground))',
    colorTextSecondary: 'hsl(var(--muted-foreground))',
    colorSuccess: 'hsl(var(--primary))',
    colorDanger: 'hsl(var(--destructive))',
    colorWarning: 'hsl(var(--accent))',
    colorNeutral: 'hsl(var(--muted))',
    fontSize: '14px',
    fontFamily: 'Inter, system-ui, sans-serif',
    borderRadius: '8px',
  },
  elements: {
    card: {
      backgroundColor: 'hsl(var(--card))',
      border: '1px solid hsl(var(--border))',
      borderRadius: '12px',
      boxShadow: '0 4px 12px -4px hsl(0 0% 0% / 0.1)',
      backdropFilter: 'none !important',
      filter: 'none !important',
      transform: 'none !important',
      transition: 'none !important',
      '&:hover': {
        transform: 'none !important',
        boxShadow: '0 4px 12px -4px hsl(0 0% 0% / 0.1)',
        backdropFilter: 'none !important',
        filter: 'none !important',
        border: '1px solid hsl(var(--border))',
      },
    },
    modalContent: {
      backgroundColor: 'hsl(var(--card))',
      border: '1px solid hsl(var(--border))',
      backdropFilter: 'none !important',
      filter: 'none !important',
      transform: 'none !important',
      transition: 'none !important',
      '&:hover': {
        transform: 'none !important',
        backdropFilter: 'none !important',
        filter: 'none !important',
        border: '1px solid hsl(var(--border))',
      },
    },
    organizationSwitcherTrigger: {
      backdropFilter: 'none !important',
      filter: 'none !important',
      transition: 'transform 0.15s ease, box-shadow 0.15s ease',
      '&:hover': {
        transform: 'translateY(-1px)',
        boxShadow: '0 4px 12px rgb(0 0 0 / 0.15)',
        backdropFilter: 'none !important',
        filter: 'none !important',
      },
    },
    organizationPreview: {
      backdropFilter: 'none !important',
      filter: 'none !important',
      transition: 'transform 0.15s ease',
      '&:hover': {
        transform: 'scale(1.02)',
        backdropFilter: 'none !important',
        filter: 'none !important',
      },
    },
    modalBackdrop: {
      backdropFilter: 'blur(4px)',
    },
    headerTitle: {
      color: 'hsl(var(--foreground))',
      fontSize: '24px',
      fontWeight: '600',
    },
    headerSubtitle: {
      color: 'hsl(var(--muted-foreground))',
    },
    formButtonPrimary: {
      backgroundColor: 'hsl(var(--primary))',
      color: 'hsl(var(--primary-foreground))',
      border: 'none',
      borderRadius: '8px',
      fontSize: '14px',
      fontWeight: '500',
      padding: '12px 24px',
      backdropFilter: 'none !important',
      filter: 'none !important',
      '&:hover': {
        backgroundColor: 'hsl(var(--primary-hover))',
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
    },
    formFieldInput: {
      backgroundColor: 'hsl(var(--background))',
      border: '1px solid hsl(var(--border))',
      borderRadius: '8px',
      color: 'hsl(var(--foreground))',
      fontSize: '14px',
      padding: '12px',
      backdropFilter: 'none !important',
      filter: 'none !important',
      '&:focus': {
        borderColor: 'hsl(var(--ring))',
        outline: 'none',
        boxShadow: '0 0 0 2px hsl(var(--ring) / 0.2)',
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
      '&:hover': {
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
    },
    formFieldLabel: {
      color: 'hsl(var(--foreground))',
      fontSize: '14px',
      fontWeight: '500',
    },
    identityPreviewText: {
      color: 'hsl(var(--muted-foreground))',
    },
    identityPreviewEditButton: {
      color: 'hsl(var(--primary))',
    },
    footer: {
      background: 'transparent',
    },
    footerActionLink: {
      color: 'hsl(var(--primary))',
      '&:hover': {
        color: 'hsl(var(--primary-hover))',
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
    },
    // Social connection buttons (Google, etc.)
    socialButtonsBlockButton: {
      backgroundColor: 'hsl(var(--background))',
      border: '1px solid hsl(var(--border))',
      borderRadius: '8px',
      color: 'hsl(var(--foreground))',
      fontSize: '14px',
      fontWeight: '500',
      padding: '12px 16px',
      backdropFilter: 'none !important',
      filter: 'none !important',
      transition: 'all 0.2s ease',
      '&:hover': {
        backgroundColor: 'hsl(var(--muted))',
        borderColor: 'hsl(var(--border))',
        filter: 'none !important',
        backdropFilter: 'none !important',
        transform: 'none !important',
      },
      '&:focus': {
        borderColor: 'hsl(var(--ring))',
        outline: 'none',
        boxShadow: '0 0 0 2px hsl(var(--ring) / 0.2)',
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
    },
    socialButtonsBlockButtonText: {
      color: 'hsl(var(--foreground))',
      fontSize: '14px',
      fontWeight: '500',
    },
    dividerLine: {
      backgroundColor: 'hsl(var(--border))',
    },
    dividerText: {
      color: 'hsl(var(--muted-foreground))',
      fontSize: '14px',
    },
    alternativeMethodsBlockButton: {
      backgroundColor: 'hsl(var(--background))',
      border: '1px solid hsl(var(--border))',
      borderRadius: '8px',
      color: 'hsl(var(--foreground))',
      fontSize: '14px',
      fontWeight: '500',
      padding: '12px 16px',
      backdropFilter: 'none !important',
      filter: 'none !important',
      transition: 'all 0.2s ease',
      '&:hover': {
        backgroundColor: 'hsl(var(--muted))',
        borderColor: 'hsl(var(--border))',
        filter: 'none !important',
        backdropFilter: 'none !important',
        transform: 'none !important',
      },
    },
    // Upload button specific styling
    fileDropAreaButton: {
      backgroundColor: 'hsl(var(--primary))',
      color: 'white !important',
      border: 'none',
      borderRadius: '8px',
      fontSize: '14px',
      fontWeight: '500',
      padding: '12px 24px',
      backdropFilter: 'none !important',
      filter: 'none !important',
      '&:hover': {
        backgroundColor: 'hsl(var(--primary-hover))',
        color: 'white !important',
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
    },
    fileDropAreaButtonPrimary: {
      backgroundColor: 'hsl(var(--primary))',
      color: 'white !important',
      border: 'none',
      borderRadius: '8px',
      fontSize: '14px',
      fontWeight: '500',
      padding: '12px 24px',
      backdropFilter: 'none !important',
      filter: 'none !important',
      '&:hover': {
        backgroundColor: 'hsl(var(--primary-hover))',
        color: 'white !important',
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
    },
    fileDropAreaBox: {
      color: 'white !important',
    },
    fileDropAreaIcon: {
      color: 'white !important',
    },
    fileDropAreaText: {
      color: 'white !important',
    },
    // Additional upload-related elements
    avatarImageActions: {
      color: 'white !important',
    },
    avatarImageActionsUpload: {
      color: 'white !important',
    },
    // Global override to remove all blur effects
    'input, button, div, span, p, h1, h2, h3, h4, h5, h6, *': {
      backdropFilter: 'none !important',
      filter: 'none !important',
      '&:hover': {
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
      '&:focus': {
        filter: 'none !important',
        backdropFilter: 'none !important',
      },
    },
  },
}

// Optimized Clerk configuration for faster performance
const clerkOptions = {
  publishableKey: PUBLISHABLE_KEY,
  appearance: clerkAppearance,
  signInFallbackRedirectUrl: "/",
  signUpFallbackRedirectUrl: "/",
};

createRoot(document.getElementById("root")!).render(
  <HelmetProvider>
    <ClerkProvider {...clerkOptions}>
      <QueryProvider>
        <CurrencyProvider>
          <App />
        </CurrencyProvider>
      </QueryProvider>
    </ClerkProvider>
  </HelmetProvider>
);
